/*
 *
 *
 *    output.h
 *
 *    Output module interface.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2019 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *
 *
 */

#ifndef __KK5JY_OUTPUT_H
#define __KK5JY_OUTPUT_H

//
//  interface OutputModule
//
class OutputModule {
	public:
		// called in sketch setup()
		virtual void Setup() = 0;

		// called in sketch loop()
		virtual void Loop() = 0;

		// called when threshold crossed, in either direction
		virtual void SetState(bool) = 0;

		// returns the module-specific clip warning level
		virtual float ClipWarning() = 0;

		// get/set the output pin
		virtual int16_t OutPin() const = 0;
		virtual void    OutPin(int16_t d) = 0;

		// get/set the LED pin
		virtual int16_t LedPin() const = 0;
		virtual void    LedPin(int16_t d) = 0;

		// get/set flag indicating whether to use AUDIO for keying
		virtual bool UseAudio() const = 0;
		virtual void UseAudio(bool b) = 0;

		// get/set flag indicating whether to use DTR pin
		virtual bool UseDTR() const = 0;
		virtual void UseDTR(bool b) = 0;

		// get/set flag indicating whether to use RTS pin
		virtual bool UseRTS() const = 0;
		virtual void UseRTS(bool b) = 0;
};

#endif // __KK5JY_OUTPUT_H
